@@ -10,11 +10,7 @@
 ** The IP masquerading functionality has been taken from openbsd.c and
 ** is distributed under the same copyright.
 **
-** This file has been modified for oidentd by Ryan McCabe <odin@numb.org>
-**
-** Modifications Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
-**
-** $Id: freebsd.c,v 1.10 2002/01/18 04:50:03 odin Exp $
+** Modifications Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
 */
 
 #include <config.h>
@@ -73,6 +69,8 @@
 #include <oidentd_options.h>
 #include <oidentd_masq.h>
 
+extern struct sockaddr_storage proxy;
+
 #ifdef INPLOOKUP_SETLOCAL
 #	define _HAVE_OLD_INPCB
 #endif
@@ -80,8 +78,6 @@
 #define N_TCB			0
 
 #ifdef MASQ_SUPPORT
-	extern struct sockaddr_storage proxy;
-
 #	define N_NATLIST	1
 #	define N_TOTAL		3
 #else
@@ -178,7 +174,6 @@ static struct socket *getlist4(	void *arg,
 	head = pcbp->inp_prev;
 
 	do {
-#ifdef MASQ_SUPPORT
 		if (opt_enabled(PROXY)) {
 			if (faddr->s_addr == SIN4(&proxy)->sin_addr.s_addr &&
 				laddr->s_addr != SIN4(&proxy)->sin_addr.s_addr &&
@@ -188,7 +183,6 @@ static struct socket *getlist4(	void *arg,
 				return (pcb.inp_socket);
 			}
 		}
-#endif
 
 		if (pcbp->inp_faddr.s_addr == faddr->s_addr &&
 			pcbp->inp_laddr.s_addr == laddr->s_addr &&
@@ -224,7 +218,6 @@ static struct socket *getlist4(	void *arg,
 		if (getbuf((u_long) head, &pcbp, sizeof(struct inpcb)) == -1)
 			break;
 
-#ifdef MASQ_SUPPORT
 		if (opt_enabled(PROXY)) {
 			if (faddr->s_addr == SIN4(&proxy)->sin_addr.s_addr &&
 				laddr->s_addr != SIN4(&proxy)->sin_addr.s_addr &&
@@ -234,7 +227,6 @@ static struct socket *getlist4(	void *arg,
 				return (pcbp.inp_socket);
 			}
 		}
-#endif
 
 		if (pcbp.inp_faddr.s_addr == faddr->s_addr &&
 			pcbp.inp_laddr.s_addr == laddr->s_addr &&
@@ -384,6 +376,7 @@ int masq(	int sock,
 
 	for (; np != NULL ; np = nat.nat_next) {
 		int ret;
+		in_port_t masq_lport;
 
 		if (getbuf((u_long) np, &nat, sizeof(nat)) == -1) {
 			debug("getbuf: %s", strerror(errno));
@@ -415,11 +408,12 @@ int masq(	int sock,
 
 		lport = ntohs(lport);
 		fport = ntohs(fport);
+		masq_lport = ntohs(nat.nat_inport);
 
 		sin_setv4(nat.nat_inip.s_addr, &ss);
 
 		if (opt_enabled(FORWARD)) {
-			ret = fwd_request(sock, lport, lport, fport, &ss);
+			ret = fwd_request(sock, lport, masq_lport, fport, &ss);
 
 			if (ret == 0)
 				return (0);
