@@ -1,6 +1,6 @@
 /*
 ** freebsd4.c - Ident lookup routines for >= FreeBSD 4
-** Copyright (C) 2000-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2000-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,11 +14,10 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: freebsd4.c,v 1.3 2001/12/31 18:47:41 odin Exp $
 */
 
 #define _GNU_SOURCE
+#define _WANT_UCRED
 
 #include <config.h>
 
@@ -47,6 +46,9 @@
 #include <oidentd.h>
 #include <oidentd_util.h>
 #include <oidentd_inet_util.h>
+#include <oidentd_options.h>
+
+extern struct sockaddr_storage proxy;
 
 int get_user4(	in_port_t lport,
 				in_port_t fport,
@@ -70,7 +72,9 @@ int get_user4(	in_port_t lport,
 	sin4[1].sin_len = sizeof(struct sockaddr_in);
 	sin4[1].sin_family = AF_INET;
 	sin4[1].sin_port = fport;
-	sin4[1].sin_addr.s_addr = SIN4(faddr)->sin_addr.s_addr;
+
+	if (!opt_enabled(PROXY) || !sin_equal(faddr, &proxy))
+		sin4[1].sin_addr.s_addr = SIN4(faddr)->sin_addr.s_addr;
 
 	ret = sysctlbyname("net.inet.tcp.getcred",
 		&ucred, &len, sin4, sizeof(sin4));
