@@ -1,6 +1,6 @@
 /*
 ** linux.c - Linux user lookup facility.
-** Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: linux.c,v 1.8 2002/01/16 06:55:07 odin Exp $
 */
 
 #define _GNU_SOURCE
@@ -30,6 +28,7 @@
 #include <pwd.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/uio.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
@@ -198,7 +197,6 @@ int get_user4(	in_port_t lport,
 		portl = (in_port_t) portl_temp;
 		portf = (in_port_t) portf_temp;
 
-#ifdef MASQ_SUPPORT
 		if (opt_enabled(PROXY)) {
 			if (faddr4 == SIN4(&proxy)->sin_addr.s_addr &&
 				remote != SIN4(&proxy)->sin_addr.s_addr &&
@@ -208,7 +206,6 @@ int get_user4(	in_port_t lport,
 				goto out_success;
 			}
 		}
-#endif
 
 		if (local == laddr4 &&
 			remote == faddr4 &&
@@ -291,9 +288,11 @@ int masq(	int sock,
 		char os[24];
 		char proto[16];
 		in_port_t mport;
-		in_port_t lportm;
-		in_port_t fportm;
+		in_port_t nport;
+		in_port_t masq_lport;
+		in_port_t masq_fport;
 		char user[MAX_ULEN];
+		in_addr_t remoten;
 		in_addr_t localm;
 		in_addr_t remotem;
 		struct sockaddr_storage ss;
@@ -301,39 +300,50 @@ int masq(	int sock,
 
 		if (netfilter == false) {
 			u_int32_t mport_temp;
-			u_int32_t lportm_temp;
-			u_int32_t fportm_temp;
+			u_int32_t masq_lport_temp;
+			u_int32_t masq_fport_temp;
 
 			ret = sscanf(buf, "%15s %X:%X %X:%X %X %*X %*d %*d %*u",
-					proto, &localm, &lportm_temp,
-					&remotem, &fportm_temp, &mport_temp);
+					proto, &localm, &masq_lport_temp,
+					&remotem, &masq_fport_temp, &mport_temp);
 
 			if (ret != 6)
 				continue;
 
 			mport = (in_port_t) mport_temp;
-			lportm = (in_port_t) lportm_temp;
-			fportm = (in_port_t) fportm_temp;
+			masq_lport = (in_port_t) masq_lport_temp;
+			masq_fport = (in_port_t) masq_fport_temp;
 		} else {
 			int l1, l2, l3, l4, r1, r2, r3, r4;
+			int nl1, nl2, nl3, nl4, nr1, nr2, nr3, nr4;
+			u_int32_t nport_temp;
 			u_int32_t mport_temp;
-			u_int32_t lportm_temp;
-			u_int32_t fportm_temp;
+			in_addr_t localn;
+			u_int32_t masq_lport_temp;
+			u_int32_t masq_fport_temp;
 
 			ret = sscanf(buf,
-				"%15s %*d %*d ESTABLISHED src=%d.%d.%d.%d dst=%d.%d.%d.%d sport=%d dport=%d %*s %*s %*s dport=%d",
-					proto, &l1, &l2, &l3, &l4, &r1, &r2, &r3, &r4,
-					&lportm_temp, &fportm_temp, &mport_temp);
+				"%15s %*d %*d ESTABLISHED src=%d.%d.%d.%d dst=%d.%d.%d.%d sport=%d dport=%d src=%d.%d.%d.%d dst=%d.%d.%d.%d sport=%d dport=%d",
+				proto, &l1, &l2, &l3, &l4, &r1, &r2, &r3, &r4, &masq_lport_temp, &masq_fport_temp,
+				&nl1, &nl2, &nl3, &nl4, &nr1, &nr2, &nr3, &nr4, &nport_temp, &mport_temp);
 
-			if (ret != 12)
+			if (ret != 21)
 				continue;
 
+			masq_lport = (in_port_t) masq_lport_temp;
+			masq_fport = (in_port_t) masq_fport_temp;
+
+			nport = (in_port_t) nport_temp;
 			mport = (in_port_t) mport_temp;
-			lportm = (in_port_t) lportm_temp;
-			fportm = (in_port_t) fportm_temp;
 
 			localm = l1 << 24 | l2 << 16 | l3 << 8 | l4;
 			remotem = r1 << 24 | r2 << 16 | r3 << 8 | r4;
+
+			localn = nl1 << 24 | nl2 << 16 | nl3 << 8 | nl4;
+			remoten = nr1 << 24 | nr2 << 16 | nr3 << 8 | nr4;
+
+			if (remotem != localn)
+				remotem = localn;
 		}
 
 		if (strcasecmp(proto, "tcp"))
@@ -342,7 +352,7 @@ int masq(	int sock,
 		if (mport != lport)
 			continue;
 
-		if (fportm != fport)
+		if (masq_fport != fport)
 			continue;
 
 		if (remotem != ntohl(SIN4(faddr)->sin_addr.s_addr)) {
@@ -361,12 +371,12 @@ int masq(	int sock,
 		if (opt_enabled(FORWARD)) {
 			char ipbuf[MAX_IPLEN];
 
-			if (fwd_request(sock, lport, lportm, fportm, &ss) == 0)
+			if (fwd_request(sock, lport, masq_lport, fport, &ss) == 0)
 				goto out_success;
 
 			get_ip(&ss, ipbuf, sizeof(ipbuf));
 
-			debug("Forward to %s (%d %d) failed", ipbuf, lportm, fportm);
+			debug("Forward to %s (%d %d) failed", ipbuf, masq_lport, fport);
 		}
 
 		ret = find_masq_entry(&ss, user, sizeof(user), os, sizeof(os));
@@ -488,7 +498,7 @@ static int lookup_tcp_diag(	struct sockaddr_storage *src_addr,
 
 		h = (struct nlmsghdr *) buf;
 
-		while (NLMSG_OK(h, ret)) {
+		while (NLMSG_OK(h, (size_t) ret)) {
 			struct tcpdiagmsg *r;
 
 			if (h->nlmsg_seq != 1) {
