@@ -7,14 +7,10 @@
 **		This program is in the public domain and may be used freely
 **		by anyone who wants to.
 **
-** This file has been modified for oidentd by Ryan McCabe <odin@numb.org>
-**
 ** OpenBSD IP masquerading support Copyright (C) 2000
 ** Slawomir Piotrowski <slawek@telsatgp.com.pl>
 **
-** Modifications Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
-**
-** $Id: openbsd.c,v 1.9 2002/01/18 04:50:03 odin Exp $
+** Modifications Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
 */
 
 #include <config.h>
@@ -60,12 +56,12 @@
 #include <oidentd_inet_util.h>
 #include <oidentd_masq.h>
 #include <oidentd_options.h>
+	
+extern struct sockaddr_storage proxy;
 
 #define N_TCB			0
 
 #ifdef MASQ_SUPPORT
-	extern struct sockaddr_storage proxy;
-
 #	define N_NATLIST	1
 #	define N_TOTAL		3
 #else
@@ -160,7 +156,6 @@ static struct socket *getlist4(	struct inpcbtable *tcbtablep,
 		if (getbuf((u_long) kpcbp, &pcb, sizeof(struct inpcb)) == -1)
 			break;
 
-#ifdef MASQ_SUPPORT
 		if (opt_enabled(PROXY)) {
 			if (faddr->s_addr == SIN4(&proxy)->sin_addr.s_addr &&
 				laddr->s_addr != SIN4(&proxy)->sin_addr.s_addr &&
@@ -170,7 +165,6 @@ static struct socket *getlist4(	struct inpcbtable *tcbtablep,
 				return (pcb.inp_socket);
 			}
 		}
-#endif
 
 		if (pcb.inp_faddr.s_addr == faddr->s_addr &&
 			pcb.inp_laddr.s_addr == laddr->s_addr &&
@@ -249,6 +243,7 @@ int masq(	int sock,
 
 	for (; np != NULL ; np = nat.nat_next) {
 		int ret;
+		in_port_t masq_lport;
 
 		if (getbuf((u_long) np, &nat, sizeof(nat)) == -1)
 			break;
@@ -278,11 +273,12 @@ int masq(	int sock,
 
 		lport = ntohs(lport);
 		fport = ntohs(fport);
+		masq_lport = ntohs(nat.nat_inport);
 
 		sin_setv4(nat.nat_inip.s_addr, &ss);
 
 		if (opt_enabled(FORWARD)) {
-			ret = fwd_request(sock, fport, lport, nat.nat_inport, &ss);
+			ret = fwd_request(sock, lport, masq_lport, fport, &ss);
 			if (ret == 0)
 				return (0);
 			else {
