@@ -7,11 +7,7 @@
 **		This program is in the public domain and may be used freely
 **		by anyone who wants to.
 **
-** This file has been modified for oidentd by Ryan McCabe <odin@numb.org>
-**
-** Modifications Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
-**
-** $Id: openbsd24.c,v 1.5 2002/01/18 04:50:03 odin Exp $
+** Modifications Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
 */
 
 #include <config.h>
@@ -40,6 +36,9 @@
 #include <oidentd.h>
 #include <oidentd_util.h>
 #include <oidentd_inet_util.h>
+#include <oidentd_options.h>
+
+extern struct sockaddr_storage proxy;
 
 /*
 ** Return the UID of the connection owner
@@ -61,9 +60,11 @@ int get_user4(	in_port_t lport,
 	tir.faddr.sa_family = AF_INET;
 	tir.faddr.sa_len = sizeof(struct sockaddr);
 	fin = (struct sockaddr_in *) &tir.faddr;
-	memcpy(&fin->sin_addr, &SIN4(faddr)->sin_addr, sizeof(struct in_addr));
 	fin->sin_port = fport;
 
+	if (!opt_enabled(PROXY) || !sin_equal(faddr, &proxy))
+		memcpy(&fin->sin_addr, &SIN4(faddr)->sin_addr, sizeof(struct in_addr));
+
 	tir.laddr.sa_family = AF_INET;
 	tir.laddr.sa_len = sizeof(struct sockaddr);
 	lin = (struct sockaddr_in *) &tir.laddr;
