@@ -1,6 +1,6 @@
 /*
 ** openbsd29.c - Low level kernel access functions for OpenBSD 2.9 and greater
-** Copyright (C) 2001-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: openbsd29.c,v 1.4 2002/01/18 04:50:03 odin Exp $
 */
 
 #include <config.h>
@@ -44,6 +42,9 @@
 #include <oidentd.h>
 #include <oidentd_util.h>
 #include <oidentd_inet_util.h>
+#include <oidentd_options.h>
+
+extern struct sockaddr_storage proxy;
 
 /*
 ** Return the UID of the connection owner
@@ -65,9 +66,11 @@ int get_user4(	in_port_t lport,
 	tir.faddr.ss_family = AF_INET;
 	tir.faddr.ss_len = sizeof(struct sockaddr);
 	fin = (struct sockaddr_in *) &tir.faddr;
-	memcpy(&fin->sin_addr, &SIN4(faddr)->sin_addr, sizeof(struct in_addr));
 	fin->sin_port = fport;
 
+	if (!opt_enabled(PROXY) || !sin_equal(faddr, &proxy))
+		memcpy(&fin->sin_addr, &SIN4(faddr)->sin_addr, sizeof(struct in_addr));
+
 	tir.laddr.ss_family = AF_INET;
 	tir.laddr.ss_len = sizeof(struct sockaddr);
 	lin = (struct sockaddr_in *) &tir.laddr;
