@@ -1,6 +1,6 @@
 /*
 ** openbsd30.c - Low level kernel access functions for OpenBSD 3.0 and greater
-** Copyright (C) 2001-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -16,8 +16,6 @@
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 **
 ** PF support by Kamil Andrusz <wizz@mniam.net>
-**
-** $Id: openbsd30.c,v 1.10 2002/01/22 21:08:31 odin Exp $
 */
 
 #include <config.h>
@@ -56,6 +54,8 @@
 #include <oidentd_masq.h>
 #include <oidentd_options.h>
 
+extern struct sockaddr_storage proxy;
+
 /*
 ** Return the UID of the connection owner
 */
@@ -76,9 +76,11 @@ int get_user4(	in_port_t lport,
 	tir.faddr.ss_family = AF_INET;
 	tir.faddr.ss_len = sizeof(struct sockaddr);
 	fin = (struct sockaddr_in *) &tir.faddr;
-	memcpy(&fin->sin_addr, &SIN4(faddr)->sin_addr, sizeof(struct in_addr));
 	fin->sin_port = fport;
 
+	if (!opt_enabled(PROXY) || !sin_equal(faddr, &proxy))
+		memcpy(&fin->sin_addr, &SIN4(faddr)->sin_addr, sizeof(struct in_addr));
+
 	tir.laddr.ss_family = AF_INET;
 	tir.laddr.ss_len = sizeof(struct sockaddr);
 	lin = (struct sockaddr_in *) &tir.laddr;
@@ -112,6 +114,7 @@ int masq(	int sock,
 	char os[24];
 	char user[MAX_ULEN];
 	struct sockaddr_storage ss;
+	in_port_t masq_lport;
 
 	if (faddr->ss_family != AF_INET || laddr->ss_family != AF_INET)
 		return (-1);
@@ -143,11 +146,12 @@ int masq(	int sock,
 
 	fport = ntohs(fport);
 	lport = ntohs(lport);
+	masq_lport = ntohs(natlook.rsport);
 
 	sin_setv4(natlook.rsaddr.v4.s_addr, &ss);
 
 	if (opt_enabled(FORWARD)) {
-		ret = fwd_request(sock, fport, lport, natlook.rsport, &ss);
+		ret = fwd_request(sock, lport, masq_lport, fport, &ss);
 		if (ret == 0)
 			return (0);
 		else {
