@@ -3,7 +3,7 @@
 **
 ** Copyright (c) 1995-1997	Casper Dik <Casper.Dik@Holland.Sun.COM>
 ** Copyright (c) 1997		Peter Eriksson <pen@lysator.liu.se>
-** Copyright (c) 2001-2002	Ryan McCabe <odin@numb.org>
+** Copyright (c) 2001-2003	Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or
 ** modify it as you wish - as long as you don't claim that you wrote
@@ -12,8 +12,6 @@
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-**
-** $Id: solaris7.c,v 1.3 2002/01/18 04:50:03 odin Exp $
 */
 
 #include <config.h>
@@ -55,7 +53,7 @@
 #include <sys/file.h>
 #include <sys/stream.h>
 
-#ifdef SOLARIS >= 7
+#if SOLARIS >= 7
 #	include <sys/dlpi.h>
 #	include <net/if_types.h>
 #endif
