@@ -1,5 +1,5 @@
-#ifndef __MISSING_H
-#define __MISSING_H
+#ifndef __IPV6_MISSING_H
+#define __IPV6_MISSING_H
 
 #ifndef EAI_NODATA
 #	define EAI_NODATA	1
@@ -7,14 +7,14 @@
 #endif
 
 #ifndef AI_PASSIVE
-#	define AI_PASSIVE        1
-#	define AI_CANONNAME      2
+#	define AI_PASSIVE		1
+#	define AI_CANONNAME		2
 #endif
 
 #ifndef NI_NUMERICHOST
-#	define NI_NUMERICHOST    2
-#	define NI_NAMEREQD       4
-#	define NI_NUMERICSERV    8
+#	define NI_NUMERICHOST	2
+#	define NI_NAMEREQD		4
+#	define NI_NUMERICSERV	8
 #endif
 
 #ifndef HAVE_STRUCT_ADDRINFO
@@ -34,7 +34,7 @@ struct addrinfo {
 
 #ifndef HAVE_GETADDRINFO
 int getaddrinfo(const char *hostname, const char *servname, 
-                const struct addrinfo *hints, struct addrinfo **res);
+				const struct addrinfo *hints, struct addrinfo **res);
 #endif
 
 #ifndef HAVE_GAI_STRERROR
@@ -47,7 +47,7 @@ void freeaddrinfo(struct addrinfo *ai);
 
 #ifndef HAVE_GETNAMEINFO
 int getnameinfo(const struct sockaddr *sa, size_t salen, char *host, 
-                size_t hostlen, char *serv, size_t servlen, int flags);
+				size_t hostlen, char *serv, size_t servlen, int flags);
 #endif
 
 #ifndef NI_MAXSERV
