@@ -1,6 +1,6 @@
 /*
 ** oidentd.h - oidentd ident (rfc1413) implementation.
-** Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: oidentd.h,v 1.25 2002/01/01 17:15:56 odin Exp $
 */
 
 #ifndef __OIDENTD_H_
@@ -121,23 +119,19 @@
 #	define debug(format, args...) do { } while (0)
 #endif
 
+#ifdef HAVE___ATTRIBUTE__
+	#define __format(x) __attribute__((format x ))
+	#define __notused __attribute__((unused))
+#else
+	#define __format(x)
+	#define __notused
+#endif
+
 typedef enum {
 	false = 0,
 	true = 1
 } bool;
 
-#ifndef HAVE_IN_ADDR_T
-	typedef u_int32_t in_addr_t;
-#endif
-
-#ifndef HAVE_IN_PORT_T
-	typedef u_int16_t in_port_t;
-#endif
-
-#ifndef HAVE_SOCKLEN_T
-	typedef u_int32_t socklen_t;
-#endif
-
 int k_open(void);
 
 #ifndef HAVE_STRUCT_SOCKADDR_STORAGE
@@ -155,11 +149,6 @@ struct sockaddr_storage {
 	#define ss_family __ss_family
 #endif
 
-int get_user(	in_port_t lport,
-				in_port_t fport,
-				struct sockaddr_storage *laddr,
-				struct sockaddr_storage *faddr);
-
 int get_user4(	in_port_t lport,
 				in_port_t fport,
 				struct sockaddr_storage *laddr,
