@@ -1,6 +1,6 @@
 /*
 ** oidentd_inet_util.c - oidentd network utility functions.
-** Copyright (C) 2001-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: oidentd_inet_util.c,v 1.32 2002/05/06 00:45:46 odin Exp $
 */
 
 #define _GNU_SOURCE
@@ -82,7 +80,7 @@ static int setup_bind(const struct addrinfo *ai, in_port_t listen_port) {
 		return (-1);
 	}
 
-	if (listen(listenfd, 0) != 0) {
+	if (listen(listenfd, SOMAXCONN) != 0) {
 		debug("listen: %s", strerror(errno));
 		return (-1);
 	}
@@ -320,7 +318,7 @@ int get_port(const char *name, in_port_t *port) {
 }
 
 /*
-** Return a 32-bit, network byte ordered ipv4 or ipv6 address.
+** Return a network byte ordered ipv4 or ipv6 address.
 */
 
 int get_addr(const char *hostname, struct sockaddr_storage *addr) {
@@ -343,7 +341,7 @@ int get_addr(const char *hostname, struct sockaddr_storage *addr) {
 			goto out_fail;
 	}
 
-	if (len < res->ai_addrlen)
+	if (len < (size_t) res->ai_addrlen)
 		goto out_fail;
 
 	memcpy(addr, res->ai_addr, res->ai_addrlen);
@@ -431,13 +429,10 @@ void sin_setv6(struct in6_addr *sin6, struct sockaddr_storage *ss) {
 ** Returns the length of the sockaddr struct.
 */
 
-inline size_t sin_len(const struct sockaddr_storage *ss) {
+inline size_t sin_len(const struct sockaddr_storage *ss __notused) {
 #ifdef WANT_IPV6
 	if (ss->ss_family == AF_INET6)
 		return (sizeof(struct sockaddr_in6));
-#else
-	/* Shut the compiler up. */
-	(void) ss;
 #endif
 
 	return (sizeof(struct sockaddr_in));
@@ -448,13 +443,10 @@ inline size_t sin_len(const struct sockaddr_storage *ss) {
 ** structure.
 */
 
-inline size_t sin_addr_len(const struct sockaddr_storage *ss) {
+inline size_t sin_addr_len(const struct sockaddr_storage *ss __notused) {
 #ifdef WANT_IPV6
 	if (ss->ss_family == AF_INET6)
 		return (sizeof(struct in6_addr));
-#else
-	/* Shut the compiler up. */
-	(void) ss;
 #endif
 
 	return (sizeof(struct in_addr));
