@@ -1,6 +1,6 @@
 /*
 ** oidentd_inet_util.h - oidentd network utility functions.
-** Copyright (C) 2001-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: oidentd_inet_util.h,v 1.16 2001/12/30 20:31:57 odin Exp $
 */
 
 #ifndef __OIDENTD_INET_UTIL_H
@@ -31,7 +29,7 @@ int get_addr(const char *const hostname, struct sockaddr_storage *g_addr);
 void get_ip(struct sockaddr_storage *ss, char *buf, size_t len);
 int get_hostname(struct sockaddr_storage *addr, char *hostname, size_t len);
 
-int sockprintf(int fd, const char *fmt, ...);
+int sockprintf(int fd, const char *fmt, ...) __format((printf, 2, 3));
 ssize_t sock_read(int fd, char *srbuf, size_t len);
 ssize_t sock_write(int sock, void *buf, size_t len);
 
