@@ -1,6 +1,6 @@
 /*
 ** oidentd_masq.h - oidentd IP masquerading handler.
-** Copyright (C) 1998-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: oidentd_masq.h,v 1.11 2002/01/16 06:55:07 odin Exp $
 */
 
 #ifndef __OIDENTD_MASQ_H
@@ -30,9 +28,9 @@ int find_masq_entry(struct sockaddr_storage *host,
 					size_t os_len);
 
 int fwd_request(int sock,
-				in_port_t fport,
-				in_port_t lport,
-				in_port_t mport,
+				in_port_t real_lport,
+				in_port_t masq_lport,
+				in_port_t real_fport,
 				struct sockaddr_storage *mrelay);
 
 #endif
