@@ -1,6 +1,6 @@
 /*
 ** oidentd_options.c - oidentd command-line handler.
-** Copyright (C) 2001-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: oidentd_options.c,v 1.30 2002/01/03 00:19:36 odin Exp $
 */
 
 #define _GNU_SOURCE
@@ -46,15 +44,13 @@
 #endif
 
 #ifdef MASQ_SUPPORT
-#	define OPTSTRING "a:c:C:def::g:hl:mo::p:P:qr:t:u:Uv"
-
+#	define OPTSTRING "a:c:C:def::g:hiIl:mo::p:P:qr:St:u:Uv"
 	extern in_port_t fwdport;
-	extern struct sockaddr_storage proxy;
-
 #else
-#	define OPTSTRING "a:c:C:deg:hl:o::p:qr:t:u:Uv"
+#	define OPTSTRING "a:c:C:deg:hiIl:o::p:P:qr:St:u:Uv"
 #endif
 
+extern struct sockaddr_storage proxy;
 extern char *failuser;
 extern char *ret_os;
 extern char *config_file;
@@ -77,11 +73,14 @@ static const struct option longopts[] = {
 	{"error",				no_argument,		0, 'e'},
 	{"group",				required_argument,	0, 'g'},
 	{"help",				no_argument,		0, 'h'},
+	{"foreground",				no_argument,		0, 'i'},
+	{"stdio",				no_argument,		0, 'I'},
 	{"limit",				required_argument,	0, 'l'},
 	{"other",				optional_argument,	0, 'o'},
 	{"port",				required_argument,	0, 'p'},
 	{"quiet",				no_argument,		0, 'q'},
 	{"reply",				required_argument,	0, 'r'},
+	{"nosyslog",				no_argument,		0, 'S'},
 	{"timeout",				required_argument,	0, 't'},
 	{"user",				required_argument,	0, 'u'},
 #ifdef HAVE_LIBUDB
@@ -91,8 +90,8 @@ static const struct option longopts[] = {
 #ifdef MASQ_SUPPORT
 	{"forward",				optional_argument,	0, 'f'},
 	{"masquerade",			no_argument,		0, 'm'},
-	{"proxy",				required_argument,	0, 'P'},
 #endif
+	{"proxy",				required_argument,	0, 'P'},
 	{NULL, 0, NULL, 0}
 };
 
@@ -210,6 +209,7 @@ int get_options(int argc, char *const argv[]) {
 				enable_opt(MASQ);
 				break;
 
+#endif
 			case 'P':
 			{
 				if (get_addr(optarg, &proxy) == -1) {
@@ -221,7 +221,6 @@ int get_options(int argc, char *const argv[]) {
 				break;
 			}
 
-#endif
 			case 'g':
 				enable_opt(CHANGE_GID);
 				if (find_group(optarg, &gid) == -1) {
@@ -230,6 +229,16 @@ int get_options(int argc, char *const argv[]) {
 				}
 				break;
 
+			/* pre-connected, as when run from inetd */
+			case 'I':
+				enable_opt(STDIO | FOREGROUND);
+				break;
+
+			/* do not become a daemon */
+			case 'i':
+				enable_opt(FOREGROUND);
+				break;
+
 			case 'l':
 			{
 				u_int32_t temp_limit;
@@ -282,6 +291,10 @@ int get_options(int argc, char *const argv[]) {
 				failuser = xstrdup(optarg);
 				break;
 
+			case 'S':
+				enable_opt(NOSYSLOG);
+				break;
+
 			case 't':
 			{
 				char *end;
@@ -341,7 +354,7 @@ int get_options(int argc, char *const argv[]) {
 	if (!opt_enabled(CHANGE_UID)) {
 		if (find_user("nobody", &uid) == -1) {
 			o_log(NORMAL,
-				"user \"nobody\" does not exist.  Using %u as default UID",
+				"user \"nobody\" does not exist. Using %u as default UID",
 				DEFAULT_UID);
 
 			uid = DEFAULT_UID;
@@ -379,14 +392,17 @@ static void print_usage(void) {
 #ifdef MASQ_SUPPORT
 "-f or --forward [<port>]     Forward requests for masqueraded hosts to the host on port <port>\n"
 "-m or --masquerade           Enable support for IP masquerading\n"
-"-P or --proxy <host>         <host> acts as a proxy, forwarding connections to us\n"
 #endif
 
+"-P or --proxy <host>         <host> acts as a proxy, forwarding connections to us\n"
 "-g or --group <group>        Run with specified group or GID\n"
+"-i or --foreground           Don't run as a daemon\n"
+"-I or --stdio                Service a single client connected to stdin/stdout then exit (use when oidentd is running from inetd/xinetd/etc).\n"
 "-l or --limit <number>       Limit the number of open connections to the specified number\n"
 "-o or --other [<os>]         Return <os> instead of the operating system.  Uses \"OTHER\" if no argument is given.\n"
 "-p or --port <port>          Listen for connections on specified port\n"
 "-q or --quiet                Suppress normal logging\n"
+"-S or --nosyslog             Write messages to stderr not syslog\n"
 "-t or --timeout <seconds>    Wait for <seconds> before closing connection\n"
 "-u or --user <user>          Run as specified user or UID\n"
 
@@ -403,6 +419,6 @@ static void print_usage(void) {
 }
 
 static void print_version(void) {
-	printf(	"oidentd " VERSION "\nRyan McCabe <odin@numb.org>\n"
+	printf(	"oidentd " VERSION " by Ryan McCabe <ryan@numb.org>\n"
 			"http://dev.ojnk.net\n");
 }
