@@ -1,6 +1,6 @@
 /*
 ** oidentd_options.h - oidentd command-line handler.
-** Copyright (C) 2001-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: oidentd_options.h,v 1.7 2002/01/01 17:15:56 odin Exp $
 */
 
 #ifndef __OIDENTD_OPTIONS_H_
@@ -32,6 +30,9 @@
 #define USEUDB				(1 << 0x07)
 #define DEBUG_MSGS			(1 << 0x08)
 #define QUIET				(1 << 0x09)
+#define FOREGROUND			(1 << 0x0a)
+#define NOSYSLOG			(1 << 0x0b)
+#define STDIO				(1 << 0x0c)
 
 bool opt_enabled(u_int32_t option);
 void disable_opt(u_int32_t option);
