@@ -1,6 +1,6 @@
 /*
 ** oidentd_user_db.c - oidentd user database routines.
-** Copyright (C) 2001-2002 Ryan McCabe <odin@numb.org>
+** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -14,8 +14,6 @@
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
-**
-** $Id: oidentd_user_db.c,v 1.16 2001/12/31 18:47:41 odin Exp $
 */
 
 #include <config.h>
@@ -87,7 +85,7 @@ static void random_ident(char *buf, size_t len) {
 		"0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
 
 	for (i = 0 ; i < len - 1 ; i++)
-		buf[i] = valid[rand() % (sizeof(valid) - 1)];
+		buf[i] = valid[randval(sizeof(valid) - 1)];
 
 	buf[i] = '\0';
 }
@@ -97,7 +95,7 @@ static void random_ident(char *buf, size_t len) {
 */
 
 static inline u_char *select_reply(const struct user_cap *user) {
-	return (user->force_data[rand() % user->num_replies]);
+	return (user->force_data[randval(user->num_replies)]);
 }
 
 /*
@@ -114,7 +112,7 @@ static inline void numeric_ident(uid_t con_uid, char *buf, size_t len) {
 */
 
 static inline void random_ident_numeric(char *buf, size_t len) {
-	snprintf(buf, len, "%s%u", UPREFIX, rand() % 100000);
+	snprintf(buf, len, "%s%u", UPREFIX, randval(100000));
 }
 
 /*
@@ -161,7 +159,7 @@ int get_ident(	const struct passwd *pwd,
 				break;
 
 			case CAP_RANDOM:
-				random_ident(reply, len);
+				random_ident(reply, MIN(12, len));
 				break;
 
 			case CAP_NUMERIC:
@@ -205,7 +203,7 @@ int get_ident(	const struct passwd *pwd,
 
 			case CAP_RANDOM:
 				if (user_db_have_cap(user_cap, CAP_RANDOM) == true) {
-					random_ident(reply, len);
+					random_ident(reply, MIN(12, len));
 					goto out_success;
 				}
 
